==> estateplat-common-1.2.4-20221123.080737-1120-sources.jar: cn/gtmap/estateplat/model/acceptance/YcslYjskSftj.java <==
package cn.gtmap.estateplat.model.acceptance;


import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:dingweiwei@gtmap.cn">dingweiwei</a>
 * @version 1.0, 2022/11/23
 * @description
 */
@Entity
@Table(name = "YCSL_YJSK_SFTJ")
public class YcslYjskSftj {
    @Id
    private String id;
    private String dzsphm;//电子税票号码
    private String zrfcsfbz;//转让方承受方标志
    private String djxh;//登记序号
    private String nsrsbh;//纳税人识别号
    private String nsrmc;//纳税人名称
    private String ybtse;//应补退税额
    private Date jkqx;//缴款期限
    private String skssjgdm;//税务机关代码
    private String kkfhm;//扣款返回码
    private String kkfhxx;//扣款返回信息
    private String proid;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getDzsphm() {
        return dzsphm;
    }

    public void setDzsphm(String dzsphm) {
        this.dzsphm = dzsphm;
    }

    public String getZrfcsfbz() {
        return zrfcsfbz;
    }

    public void setZrfcsfbz(String zrfcsfbz) {
        this.zrfcsfbz = zrfcsfbz;
    }

    public String getDjxh() {
        return djxh;
    }

    public void setDjxh(String djxh) {
        this.djxh = djxh;
    }

    public String getNsrsbh() {
        return nsrsbh;
    }

    public void setNsrsbh(String nsrsbh) {
        this.nsrsbh = nsrsbh;
    }

    public String getNsrmc() {
        return nsrmc;
    }

    public void setNsrmc(String nsrmc) {
        this.nsrmc = nsrmc;
    }

    public String getYbtse() {
        return ybtse;
    }

    public void setYbtse(String ybtse) {
        this.ybtse = ybtse;
    }

    public Date getJkqx() {
        return jkqx;
    }

    public void setJkqx(Date jkqx) {
        this.jkqx = jkqx;
    }

    public String getSkssjgdm() {
        return skssjgdm;
    }

    public void setSkssjgdm(String skssjgdm) {
        this.skssjgdm = skssjgdm;
    }

    public String getKkfhm() {
        return kkfhm;
    }

    public void setKkfhm(String kkfhm) {
        this.kkfhm = kkfhm;
    }

    public String getKkfhxx() {
        return kkfhxx;
    }

    public void setKkfhxx(String kkfhxx) {
        this.kkfhxx = kkfhxx;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }
}

==> estateplat-common-1.2.4-20231227.085211-1208-sources.jar: cn/gtmap/estateplat/model/acceptance/YcslYjskSftj.java <==
package cn.gtmap.estateplat.model.acceptance;


import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:dingweiwei@gtmap.cn">dingweiwei</a>
 * @version 1.0, 2022/11/23
 * @description
 */
@Entity
@Table(name = "YCSL_YJSK_SFTJ")
public class YcslYjskSftj {
    @Id
    private String id;
    private String dzsphm;//电子税票号码
    private String zrfcsfbz;//转让方承受方标志
    private String djxh;//登记序号
    private String nsrsbh;//纳税人识别号
    private String nsrmc;//纳税人名称
    private Double ybtse;//应补退税额
    private Date jkqx;//缴款期限
    private String skssjgdm;//税务机关代码
    private String kkfhm;//扣款返回码
    private String kkfhxx;//扣款返回信息
    private String proid;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getDzsphm() {
        return dzsphm;
    }

    public void setDzsphm(String dzsphm) {
        this.dzsphm = dzsphm;
    }

    public String getZrfcsfbz() {
        return zrfcsfbz;
    }

    public void setZrfcsfbz(String zrfcsfbz) {
        this.zrfcsfbz = zrfcsfbz;
    }

    public String getDjxh() {
        return djxh;
    }

    public void setDjxh(String djxh) {
        this.djxh = djxh;
    }

    public String getNsrsbh() {
        return nsrsbh;
    }

    public void setNsrsbh(String nsrsbh) {
        this.nsrsbh = nsrsbh;
    }

    public String getNsrmc() {
        return nsrmc;
    }

    public void setNsrmc(String nsrmc) {
        this.nsrmc = nsrmc;
    }

    public Double getYbtse() {
        return ybtse;
    }

    public void setYbtse(Double ybtse) {
        this.ybtse = ybtse;
    }

    public Date getJkqx() {
        return jkqx;
    }

    public void setJkqx(Date jkqx) {
        this.jkqx = jkqx;
    }

    public String getSkssjgdm() {
        return skssjgdm;
    }

    public void setSkssjgdm(String skssjgdm) {
        this.skssjgdm = skssjgdm;
    }

    public String getKkfhm() {
        return kkfhm;
    }

    public void setKkfhm(String kkfhm) {
        this.kkfhm = kkfhm;
    }

    public String getKkfhxx() {
        return kkfhxx;
    }

    public void setKkfhxx(String kkfhxx) {
        this.kkfhxx = kkfhxx;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }
}
